Trestle was designed and opensourced by a team based at [IBM Research](https://www.research.ibm.com/) and others around the world.  The list includes:

Christopher Butler - [butler54](https://github.com/butler54)

Bruno Marques - [brunomarq](https://github.com/brunomarq)

Lenin Mehedy - [leninmehedy](https://github.com/leninmehedy)

Simon Metson - [drsm79](https://github.com/drsm79)

Frank Suits - [fsuits](https://github.com/fsuits)

Jeff Tan - [jeffdmgit](https://github.com/jeffdmgit)

Nebula Alam - [aNebula](https://github.com/aNebula)

Vikas Agarwal [vikas-agarwal76](https://github.com/vikas-agarwal76)

Lou Degenaro [degenaro](https://github.com/degenaro)
